Learn R Programming

nlfh (version 0.1.0)

print.summary.nlfh_fit: Print a Summary of a Fitted Nonlinear Fay-Herriot Model

Description

Prints a compact view of a summary.nlfh_fit object. Large area-level and coefficient summaries are truncated to their first rows.

Usage

# S3 method for summary.nlfh_fit
print(x, digits = 4, max_rows = 6, ...)

Value

The input object x, invisibly.

Arguments

x

An object returned by summary.nlfh_fit().

digits

Number of significant digits to print.

max_rows

Maximum number of rows to print from coefficient and area-level summaries.

...

Additional arguments passed to methods. Currently unused.